netapp_ontap.models.disk_stats API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.disk_stats`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DiskStatsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DiskStats object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `average_latency: Size GET`

    Average I/O latency across all active paths, in milliseconds.

    Example: 3

  `iops_total: Size GET`

    Total I/O operations per second read and written to this disk across all active paths.

    Example: 12854

  `path_error_count: Size GET`

    Disk path error count; failed I/O operations.

    Example: 0

  `power_on_hours: Size GET`

    Hours powered on.

    Example: 21016

  `throughput: Size GET`

    Total disk throughput per second across all active paths, in bytes.

    Example: 1957888